/**
 * Represents an extension in the framework.
 *
 * @public
 * @module Xethya
 * @class ExtensionBase
 */

/**
 * Builds an extension using Babel with Rollup. The extension will be exported
 * in ES and UMD module formats into a `dist` folder, with the following name
 * format:
 *
 * ```
 *   dist/<package.name>.<format>.js
 * ```
 *
 * In order for an extension to be buildable, it must contain the following
 * configuration in its `package.json` file:
 *
 * ```json
 * {
 *   "xethya": {
 *     "extensionName": "Module.Extension"
 *   }
 * }
 * ```
 *
 * This will export the extension into the `Xethya.Module.Extension` namespace.
 * Any classes you define will live there.
 *
 * To register the task in your local Gulp file, add the following line:
 *
 * ```js
 * require('xethya-extension-base/tasks/build');
 * ```
 *
 * Then, use it with a globally-installed version of Gulp:
 *
 * ```bash
 * gulp extension:build
 * ```
 *
 * or add it to your `package.json` file as a `run script`:
 *
 * ```json
 * {
 *   "scripts": {
 *     "build": "gulp extension:build"
 *   }
 * }
 * ```
 *
 * and then run it as:
 *
 * ```bash
 * npm run build
 * ```
 *
 * @public
 * @memberof ExtensionBase
 * @method extension:build
 */

/**
 * Runs the extension's test suite. This will spawn a Karma server, hooked-up
 * with Mocha, Chai and Sinon, using headless Chrome as browser.
 *
 * Test files must reside in the `test` folder, and use the `.spec.js` suffix.
 * Tests can be written in ES6, without using `import`. The module you're testing
 * is available globally under the `Xethya` namespace, as specified by
 * `extension:build`.
 *
 * To register the task in your local Gulp file, add the following line:
 *
 * ```js
 * require('xethya-extension-base/tasks/test');
 * ```
 *
 * Then, use it with a globally-installed version of Gulp:
 *
 * ```bash
 * gulp extension:test
 * ```
 *
 * or add it to your `package.json` file as a `run script`:
 *
 * ```json
 * {
 *   "scripts": {
 *     "test": "gulp extension:test"
 *   }
 * }
 * ```
 *
 * and then run it as:
 *
 * ```bash
 * npm run test
 * ```
 *
 * @public
 * @memberof ExtensionBase
 * @method extension:test
 */

/**
 * Builds the extension's documentation. It'll scan any *.js files
 * living in `src/` and create a `README.md` file in `src/`.
 *
 * Proper usage of JSDoc is required for this task to run correctly.
 * `@module` declaration is mandatory.
 *
 * To register the task in your local Gulp file, add the following line:
 *
 * ```js
 * require('xethya-extension-base/tasks/docs');
 * ```
 *
 * Then, use it with a globally-installed version of Gulp:
 *
 * ```bash
 * gulp extension:docs
 * ```
 *
 * or add it to your `package.json` file as a `run script`:
 *
 * ```json
 * {
 *   "scripts": {
 *     "test": "gulp extension:docs"
 *   }
 * }
 * ```
 *
 * and then run it as:
 *
 * ```bash
 * npm run docs
 * ```
 *
 * @public
 * @memberof ExtensionBase
 * @method extension:docs
 */
